local base = {}

local version_size = 64

if data.raw.item["storage-tank"] and data.raw.item["storage-tank"].icon_size ~= version_size then
  version_size = data.raw.item["storage-tank"].icon_size
end

base.item = {
      icon_size = version_size,
      icons = {
        {
          icon = "__base__/graphics/icons/storage-tank.png",
          tint = {
            b = 1,
            g = 1,
            r = 1
          }
        }
      },
      name = "-storage-tank",
      localised_name = {
        "item-name.fill-storage-tank",
        {
          "fluid-name.water"
        },
        {
          "entity-name.storage-tank"
        }
      },
      order = "ba[water-barrel]",
      place_result = "storage-tank",
      stack_size = 1,
      subgroup = "fill-storage-tank",
      type = "item"
}


base.recipe_fill = {
  allow_decomposition = false,
  category = "crafting-with-fluid",
  enabled = false,
  -- energy_required is base on time taken to pump fluid in and out (12k/s), with room for useful speed-ups (100% faster maxes out a pump)
  energy_required = data.raw["storage-tank"]["storage-tank"].fluid_box.base_area * 100/(1200*5),
  icons = {
    {
      icon = "__base__/graphics/icons/storage-tank.png",
      icon_size = version_size
    },
--[[
    {
      icon = "__base__/graphics/icons/fluid/barreling/barrel-fill-side-mask.png",
      icon_size = 32,
      tint = {
        a = 0.75,
        b = 0.6,
        g = 0.34000000000000004,
        r = 0
      }
    },
    {
      icon = "__base__/graphics/icons/fluid/barreling/barrel-fill-top-mask.png",
      icon_size = 32,
      tint = {
        a = 0.75,
        b = 0.7,
        g = 0.7,
        r = 0.7
      }
    },
--]]
    {
      icon = "__base__/graphics/icons/fluid/water.png",
      icon_size = version_size,
      scale = 0.25,
      shift = {
        4,
        -8
      }
    }
  },
  ingredients = {
    {
      amount = data.raw["storage-tank"]["storage-tank"].fluid_box.base_area * 100,
      catalyst_amount = data.raw["storage-tank"]["storage-tank"].fluid_box.base_area * 100,
      name = "water",
      type = "fluid"
    },
    {
      amount = 1,
      catalyst_amount = 1,
      name = "storage-tank",
      type = "item"
    }
  },
  localised_name = {
    "recipe-name.fill-storage-tank",
    {
      "fluid-name.water"
    },
    {
      "entity-name.storage-tank"
    }
--[[
    {
      "recipe-name.fill-barrel",
    },
--]]
  },
  name = "fill-water-storage-tank",
  order = "b[fill-water-storage-tank]",
  results = {
    {
      amount = 1,
      catalyst_amount = 1,
      name = "water-storage-tank",
      type = "item"
    }
  },
  subgroup = "fill-storage-tank",
  type = "recipe"
}

base.recipe_empty = {
  allow_decomposition = false,
  category = "crafting-with-fluid",
  enabled = false,
  energy_required = base.recipe_fill.energy_required,
--  icon_size = 32,
  icons = {
	{
      icon = "__base__/graphics/icons/storage-tank.png",
	  icon_size = version_size,
	  tint = {
		b = 1,
		g = 1,
		r = 1
	  }
	},
--[[
	{
	  icon = "__base__/graphics/icons/fluid/barreling/barrel-empty-side-mask.png",
	  icon_size = 32,
	  tint = {
		a = 0.75,
		b = 0.6,
		g = 0.34000000000000004,
		r = 0
	  }
	},
	{
	  icon = "__base__/graphics/icons/fluid/barreling/barrel-empty-top-mask.png",
	  icon_size = 32,
	  tint = {
		a = 0.75,
		b = 0.7,
		g = 0.7,
		r = 0.7
	  }
	},
--]]
	{
	  icon = "__base__/graphics/icons/fluid/water.png",
	  icon_size = version_size,
	  scale = 0.25,
	  shift = {
		7,
		8
	  }
	}
  },
  ingredients = {
	{
	  amount = 1,
	  catalyst_amount = 1,
	  name = "water-barrel",
	  type = "item"
	}
  },
  localised_name = {
	"recipe-name.empty-filled-storage-tank",
	{
	  "fluid-name.water"
	},
    {
      "entity-name.storage-tank"
    }
  },
  name = "empty-water-storage-tank",
  order = "c[empty-water-storage-tank]",
  results = {
	{
	  amount = base.recipe_fill.ingredients[1].amount,
	  catalyst_amount = base.recipe_fill.ingredients[1].amount,
	  name = "water",
	  type = "fluid"
	},
	{
	  amount = 1,
	  catalyst_amount = 1,
	  name = "storage-tank",
	  type = "item"
	}
  },
  subgroup = "empty-storage-tank",
  type = "recipe"
}

return base